# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetExternalLinkResult',
    'AwaitableGetExternalLinkResult',
    'get_external_link',
    'get_external_link_output',
]

@pulumi.output_type
class GetExternalLinkResult:
    """
    A collection of values returned by getExternalLink.
    """
    def __init__(__self__, created_epoch_millis=None, creator_id=None, description=None, id=None, is_log_integration=None, metric_filter_regex=None, name=None, point_tag_filter_regexes=None, source_filter_regex=None, template=None, updated_epoch_millis=None, updater_id=None):
        if created_epoch_millis and not isinstance(created_epoch_millis, int):
            raise TypeError("Expected argument 'created_epoch_millis' to be a int")
        pulumi.set(__self__, "created_epoch_millis", created_epoch_millis)
        if creator_id and not isinstance(creator_id, str):
            raise TypeError("Expected argument 'creator_id' to be a str")
        pulumi.set(__self__, "creator_id", creator_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_log_integration and not isinstance(is_log_integration, bool):
            raise TypeError("Expected argument 'is_log_integration' to be a bool")
        pulumi.set(__self__, "is_log_integration", is_log_integration)
        if metric_filter_regex and not isinstance(metric_filter_regex, str):
            raise TypeError("Expected argument 'metric_filter_regex' to be a str")
        pulumi.set(__self__, "metric_filter_regex", metric_filter_regex)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if point_tag_filter_regexes and not isinstance(point_tag_filter_regexes, dict):
            raise TypeError("Expected argument 'point_tag_filter_regexes' to be a dict")
        pulumi.set(__self__, "point_tag_filter_regexes", point_tag_filter_regexes)
        if source_filter_regex and not isinstance(source_filter_regex, str):
            raise TypeError("Expected argument 'source_filter_regex' to be a str")
        pulumi.set(__self__, "source_filter_regex", source_filter_regex)
        if template and not isinstance(template, str):
            raise TypeError("Expected argument 'template' to be a str")
        pulumi.set(__self__, "template", template)
        if updated_epoch_millis and not isinstance(updated_epoch_millis, int):
            raise TypeError("Expected argument 'updated_epoch_millis' to be a int")
        pulumi.set(__self__, "updated_epoch_millis", updated_epoch_millis)
        if updater_id and not isinstance(updater_id, str):
            raise TypeError("Expected argument 'updater_id' to be a str")
        pulumi.set(__self__, "updater_id", updater_id)

    @_builtins.property
    @pulumi.getter(name="createdEpochMillis")
    def created_epoch_millis(self) -> _builtins.int:
        """
        The timestamp in epoch milliseconds indicating when the external link is created.
        """
        return pulumi.get(self, "created_epoch_millis")

    @_builtins.property
    @pulumi.getter(name="creatorId")
    def creator_id(self) -> _builtins.str:
        """
        The ID of the user who created the external link.
        """
        return pulumi.get(self, "creator_id")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Human-readable description of this link.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the external link.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isLogIntegration")
    def is_log_integration(self) -> _builtins.bool:
        """
        Whether this is a "Log Integration" subType of external link.
        """
        return pulumi.get(self, "is_log_integration")

    @_builtins.property
    @pulumi.getter(name="metricFilterRegex")
    def metric_filter_regex(self) -> _builtins.str:
        """
        Controls whether a link is displayed in the context menu of a highlighted series. If present, the metric name of the highlighted series must match this regular expression in order for the link to be displayed.
        """
        return pulumi.get(self, "metric_filter_regex")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the external link.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="pointTagFilterRegexes")
    def point_tag_filter_regexes(self) -> Mapping[str, _builtins.str]:
        """
        (Optional) Controls whether a link is displayed in the context menu of a highlighted
        series. This is a map from string to regular expression. The highlighted series must contain point tags whose
        keys are present in the keys of this map and whose values match the regular expressions associated with those
        keys in order for the link to be displayed.
        """
        return pulumi.get(self, "point_tag_filter_regexes")

    @_builtins.property
    @pulumi.getter(name="sourceFilterRegex")
    def source_filter_regex(self) -> _builtins.str:
        """
        Controls whether a link is displayed in the context menu of a highlighted series. If present, the source name of the highlighted series must match this regular expression in order for the link to be displayed.
        """
        return pulumi.get(self, "source_filter_regex")

    @_builtins.property
    @pulumi.getter
    def template(self) -> _builtins.str:
        """
        The mustache template for the link. The template must expand to a full URL, including scheme, origin, etc.
        """
        return pulumi.get(self, "template")

    @_builtins.property
    @pulumi.getter(name="updatedEpochMillis")
    def updated_epoch_millis(self) -> _builtins.int:
        """
        The timestamp in epoch milliseconds indicating when the external link is updated.
        """
        return pulumi.get(self, "updated_epoch_millis")

    @_builtins.property
    @pulumi.getter(name="updaterId")
    def updater_id(self) -> _builtins.str:
        """
        The ID of the user who updated the external link.
        """
        return pulumi.get(self, "updater_id")


class AwaitableGetExternalLinkResult(GetExternalLinkResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetExternalLinkResult(
            created_epoch_millis=self.created_epoch_millis,
            creator_id=self.creator_id,
            description=self.description,
            id=self.id,
            is_log_integration=self.is_log_integration,
            metric_filter_regex=self.metric_filter_regex,
            name=self.name,
            point_tag_filter_regexes=self.point_tag_filter_regexes,
            source_filter_regex=self.source_filter_regex,
            template=self.template,
            updated_epoch_millis=self.updated_epoch_millis,
            updater_id=self.updater_id)


def get_external_link(id: Optional[_builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetExternalLinkResult:
    """
    Use this data source to get information about a Wavefront external link by its ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get the information about a specific external links.
    example = wavefront.get_external_link(id="sample-external-link-id")
    ```


    :param _builtins.str id: The ID of the external link.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('wavefront:index/getExternalLink:getExternalLink', __args__, opts=opts, typ=GetExternalLinkResult).value

    return AwaitableGetExternalLinkResult(
        created_epoch_millis=pulumi.get(__ret__, 'created_epoch_millis'),
        creator_id=pulumi.get(__ret__, 'creator_id'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        is_log_integration=pulumi.get(__ret__, 'is_log_integration'),
        metric_filter_regex=pulumi.get(__ret__, 'metric_filter_regex'),
        name=pulumi.get(__ret__, 'name'),
        point_tag_filter_regexes=pulumi.get(__ret__, 'point_tag_filter_regexes'),
        source_filter_regex=pulumi.get(__ret__, 'source_filter_regex'),
        template=pulumi.get(__ret__, 'template'),
        updated_epoch_millis=pulumi.get(__ret__, 'updated_epoch_millis'),
        updater_id=pulumi.get(__ret__, 'updater_id'))
def get_external_link_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetExternalLinkResult]:
    """
    Use this data source to get information about a Wavefront external link by its ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get the information about a specific external links.
    example = wavefront.get_external_link(id="sample-external-link-id")
    ```


    :param _builtins.str id: The ID of the external link.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('wavefront:index/getExternalLink:getExternalLink', __args__, opts=opts, typ=GetExternalLinkResult)
    return __ret__.apply(lambda __response__: GetExternalLinkResult(
        created_epoch_millis=pulumi.get(__response__, 'created_epoch_millis'),
        creator_id=pulumi.get(__response__, 'creator_id'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        is_log_integration=pulumi.get(__response__, 'is_log_integration'),
        metric_filter_regex=pulumi.get(__response__, 'metric_filter_regex'),
        name=pulumi.get(__response__, 'name'),
        point_tag_filter_regexes=pulumi.get(__response__, 'point_tag_filter_regexes'),
        source_filter_regex=pulumi.get(__response__, 'source_filter_regex'),
        template=pulumi.get(__response__, 'template'),
        updated_epoch_millis=pulumi.get(__response__, 'updated_epoch_millis'),
        updater_id=pulumi.get(__response__, 'updater_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DashboardArgs', 'Dashboard']

@pulumi.input_type
class DashboardArgs:
    def __init__(__self__, *,
                 description: pulumi.Input[_builtins.str],
                 sections: pulumi.Input[Sequence[pulumi.Input['DashboardSectionArgs']]],
                 tags: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 url: pulumi.Input[_builtins.str],
                 can_modifies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 can_views: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 display_query_parameters: Optional[pulumi.Input[_builtins.bool]] = None,
                 display_section_table_of_contents: Optional[pulumi.Input[_builtins.bool]] = None,
                 event_filter_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameter_details: Optional[pulumi.Input[Sequence[pulumi.Input['DashboardParameterDetailArgs']]]] = None):
        """
        The set of arguments for constructing a Dashboard resource.
        :param pulumi.Input[_builtins.str] description: Human-readable description of the dashboard.
        :param pulumi.Input[Sequence[pulumi.Input['DashboardSectionArgs']]] sections: Dashboard chart sections. See dashboard sections.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A set of tags to assign to this resource.
        :param pulumi.Input[_builtins.str] url: Unique identifier, also a URL slug of the dashboard.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] can_modifies: A list of users/groups/roles that can modify the dashboard.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] can_views: A list of users/groups/roles that can view the dashboard.
        :param pulumi.Input[_builtins.bool] display_query_parameters: Whether the dashboard parameters section is opened by default when the dashboard
               is shown.
        :param pulumi.Input[_builtins.bool] display_section_table_of_contents: Whether the "pills" quick-linked the sections of the dashboard are
               displayed by default when the dashboard is shown.
        :param pulumi.Input[_builtins.str] event_filter_type: How charts belonging to this dashboard should display events. `BYCHART` is default if
               unspecified. Valid options are: `BYCHART`, `AUTOMATIC`, `ALL`, `NONE`, `BYDASHBOARD`, and `BYCHARTANDDASHBOARD`.
        :param pulumi.Input[_builtins.str] name: Name of the dashboard.
        :param pulumi.Input[Sequence[pulumi.Input['DashboardParameterDetailArgs']]] parameter_details: The current JSON representation of dashboard parameters. See parameter details.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "sections", sections)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "url", url)
        if can_modifies is not None:
            pulumi.set(__self__, "can_modifies", can_modifies)
        if can_views is not None:
            pulumi.set(__self__, "can_views", can_views)
        if display_query_parameters is not None:
            pulumi.set(__self__, "display_query_parameters", display_query_parameters)
        if display_section_table_of_contents is not None:
            pulumi.set(__self__, "display_section_table_of_contents", display_section_table_of_contents)
        if event_filter_type is not None:
            pulumi.set(__self__, "event_filter_type", event_filter_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parameter_details is not None:
            pulumi.set(__self__, "parameter_details", parameter_details)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Input[_builtins.str]:
        """
        Human-readable description of the dashboard.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def sections(self) -> pulumi.Input[Sequence[pulumi.Input['DashboardSectionArgs']]]:
        """
        Dashboard chart sections. See dashboard sections.
        """
        return pulumi.get(self, "sections")

    @sections.setter
    def sections(self, value: pulumi.Input[Sequence[pulumi.Input['DashboardSectionArgs']]]):
        pulumi.set(self, "sections", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        A set of tags to assign to this resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier, also a URL slug of the dashboard.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "url", value)

    @_builtins.property
    @pulumi.getter(name="canModifies")
    def can_modifies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of users/groups/roles that can modify the dashboard.
        """
        return pulumi.get(self, "can_modifies")

    @can_modifies.setter
    def can_modifies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "can_modifies", value)

    @_builtins.property
    @pulumi.getter(name="canViews")
    def can_views(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of users/groups/roles that can view the dashboard.
        """
        return pulumi.get(self, "can_views")

    @can_views.setter
    def can_views(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "can_views", value)

    @_builtins.property
    @pulumi.getter(name="displayQueryParameters")
    def display_query_parameters(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the dashboard parameters section is opened by default when the dashboard
        is shown.
        """
        return pulumi.get(self, "display_query_parameters")

    @display_query_parameters.setter
    def display_query_parameters(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "display_query_parameters", value)

    @_builtins.property
    @pulumi.getter(name="displaySectionTableOfContents")
    def display_section_table_of_contents(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the "pills" quick-linked the sections of the dashboard are
        displayed by default when the dashboard is shown.
        """
        return pulumi.get(self, "display_section_table_of_contents")

    @display_section_table_of_contents.setter
    def display_section_table_of_contents(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "display_section_table_of_contents", value)

    @_builtins.property
    @pulumi.getter(name="eventFilterType")
    def event_filter_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        How charts belonging to this dashboard should display events. `BYCHART` is default if
        unspecified. Valid options are: `BYCHART`, `AUTOMATIC`, `ALL`, `NONE`, `BYDASHBOARD`, and `BYCHARTANDDASHBOARD`.
        """
        return pulumi.get(self, "event_filter_type")

    @event_filter_type.setter
    def event_filter_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "event_filter_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the dashboard.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="parameterDetails")
    def parameter_details(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DashboardParameterDetailArgs']]]]:
        """
        The current JSON representation of dashboard parameters. See parameter details.
        """
        return pulumi.get(self, "parameter_details")

    @parameter_details.setter
    def parameter_details(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DashboardParameterDetailArgs']]]]):
        pulumi.set(self, "parameter_details", value)


@pulumi.input_type
class _DashboardState:
    def __init__(__self__, *,
                 can_modifies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 can_views: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_query_parameters: Optional[pulumi.Input[_builtins.bool]] = None,
                 display_section_table_of_contents: Optional[pulumi.Input[_builtins.bool]] = None,
                 event_filter_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameter_details: Optional[pulumi.Input[Sequence[pulumi.Input['DashboardParameterDetailArgs']]]] = None,
                 sections: Optional[pulumi.Input[Sequence[pulumi.Input['DashboardSectionArgs']]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Dashboard resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] can_modifies: A list of users/groups/roles that can modify the dashboard.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] can_views: A list of users/groups/roles that can view the dashboard.
        :param pulumi.Input[_builtins.str] description: Human-readable description of the dashboard.
        :param pulumi.Input[_builtins.bool] display_query_parameters: Whether the dashboard parameters section is opened by default when the dashboard
               is shown.
        :param pulumi.Input[_builtins.bool] display_section_table_of_contents: Whether the "pills" quick-linked the sections of the dashboard are
               displayed by default when the dashboard is shown.
        :param pulumi.Input[_builtins.str] event_filter_type: How charts belonging to this dashboard should display events. `BYCHART` is default if
               unspecified. Valid options are: `BYCHART`, `AUTOMATIC`, `ALL`, `NONE`, `BYDASHBOARD`, and `BYCHARTANDDASHBOARD`.
        :param pulumi.Input[_builtins.str] name: Name of the dashboard.
        :param pulumi.Input[Sequence[pulumi.Input['DashboardParameterDetailArgs']]] parameter_details: The current JSON representation of dashboard parameters. See parameter details.
        :param pulumi.Input[Sequence[pulumi.Input['DashboardSectionArgs']]] sections: Dashboard chart sections. See dashboard sections.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A set of tags to assign to this resource.
        :param pulumi.Input[_builtins.str] url: Unique identifier, also a URL slug of the dashboard.
        """
        if can_modifies is not None:
            pulumi.set(__self__, "can_modifies", can_modifies)
        if can_views is not None:
            pulumi.set(__self__, "can_views", can_views)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_query_parameters is not None:
            pulumi.set(__self__, "display_query_parameters", display_query_parameters)
        if display_section_table_of_contents is not None:
            pulumi.set(__self__, "display_section_table_of_contents", display_section_table_of_contents)
        if event_filter_type is not None:
            pulumi.set(__self__, "event_filter_type", event_filter_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parameter_details is not None:
            pulumi.set(__self__, "parameter_details", parameter_details)
        if sections is not None:
            pulumi.set(__self__, "sections", sections)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter(name="canModifies")
    def can_modifies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of users/groups/roles that can modify the dashboard.
        """
        return pulumi.get(self, "can_modifies")

    @can_modifies.setter
    def can_modifies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "can_modifies", value)

    @_builtins.property
    @pulumi.getter(name="canViews")
    def can_views(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of users/groups/roles that can view the dashboard.
        """
        return pulumi.get(self, "can_views")

    @can_views.setter
    def can_views(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "can_views", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Human-readable description of the dashboard.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="displayQueryParameters")
    def display_query_parameters(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the dashboard parameters section is opened by default when the dashboard
        is shown.
        """
        return pulumi.get(self, "display_query_parameters")

    @display_query_parameters.setter
    def display_query_parameters(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "display_query_parameters", value)

    @_builtins.property
    @pulumi.getter(name="displaySectionTableOfContents")
    def display_section_table_of_contents(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the "pills" quick-linked the sections of the dashboard are
        displayed by default when the dashboard is shown.
        """
        return pulumi.get(self, "display_section_table_of_contents")

    @display_section_table_of_contents.setter
    def display_section_table_of_contents(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "display_section_table_of_contents", value)

    @_builtins.property
    @pulumi.getter(name="eventFilterType")
    def event_filter_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        How charts belonging to this dashboard should display events. `BYCHART` is default if
        unspecified. Valid options are: `BYCHART`, `AUTOMATIC`, `ALL`, `NONE`, `BYDASHBOARD`, and `BYCHARTANDDASHBOARD`.
        """
        return pulumi.get(self, "event_filter_type")

    @event_filter_type.setter
    def event_filter_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "event_filter_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the dashboard.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="parameterDetails")
    def parameter_details(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DashboardParameterDetailArgs']]]]:
        """
        The current JSON representation of dashboard parameters. See parameter details.
        """
        return pulumi.get(self, "parameter_details")

    @parameter_details.setter
    def parameter_details(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DashboardParameterDetailArgs']]]]):
        pulumi.set(self, "parameter_details", value)

    @_builtins.property
    @pulumi.getter
    def sections(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DashboardSectionArgs']]]]:
        """
        Dashboard chart sections. See dashboard sections.
        """
        return pulumi.get(self, "sections")

    @sections.setter
    def sections(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DashboardSectionArgs']]]]):
        pulumi.set(self, "sections", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A set of tags to assign to this resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier, also a URL slug of the dashboard.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "url", value)


@pulumi.type_token("wavefront:index/dashboard:Dashboard")
class Dashboard(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 can_modifies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 can_views: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_query_parameters: Optional[pulumi.Input[_builtins.bool]] = None,
                 display_section_table_of_contents: Optional[pulumi.Input[_builtins.bool]] = None,
                 event_filter_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameter_details: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DashboardParameterDetailArgs', 'DashboardParameterDetailArgsDict']]]]] = None,
                 sections: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DashboardSectionArgs', 'DashboardSectionArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Provides a Wavefront Dashboard resource. This allows dashboards to be created, updated, and deleted.

        ## Example Usage

        ## Import

        Dashboards can be imported by using the `id`, e.g.:

        ```sh
        $ pulumi import wavefront:index/dashboard:Dashboard dashboard tftestimport
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] can_modifies: A list of users/groups/roles that can modify the dashboard.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] can_views: A list of users/groups/roles that can view the dashboard.
        :param pulumi.Input[_builtins.str] description: Human-readable description of the dashboard.
        :param pulumi.Input[_builtins.bool] display_query_parameters: Whether the dashboard parameters section is opened by default when the dashboard
               is shown.
        :param pulumi.Input[_builtins.bool] display_section_table_of_contents: Whether the "pills" quick-linked the sections of the dashboard are
               displayed by default when the dashboard is shown.
        :param pulumi.Input[_builtins.str] event_filter_type: How charts belonging to this dashboard should display events. `BYCHART` is default if
               unspecified. Valid options are: `BYCHART`, `AUTOMATIC`, `ALL`, `NONE`, `BYDASHBOARD`, and `BYCHARTANDDASHBOARD`.
        :param pulumi.Input[_builtins.str] name: Name of the dashboard.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DashboardParameterDetailArgs', 'DashboardParameterDetailArgsDict']]]] parameter_details: The current JSON representation of dashboard parameters. See parameter details.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DashboardSectionArgs', 'DashboardSectionArgsDict']]]] sections: Dashboard chart sections. See dashboard sections.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A set of tags to assign to this resource.
        :param pulumi.Input[_builtins.str] url: Unique identifier, also a URL slug of the dashboard.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DashboardArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Wavefront Dashboard resource. This allows dashboards to be created, updated, and deleted.

        ## Example Usage

        ## Import

        Dashboards can be imported by using the `id`, e.g.:

        ```sh
        $ pulumi import wavefront:index/dashboard:Dashboard dashboard tftestimport
        ```

        :param str resource_name: The name of the resource.
        :param DashboardArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DashboardArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 can_modifies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 can_views: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_query_parameters: Optional[pulumi.Input[_builtins.bool]] = None,
                 display_section_table_of_contents: Optional[pulumi.Input[_builtins.bool]] = None,
                 event_filter_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameter_details: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DashboardParameterDetailArgs', 'DashboardParameterDetailArgsDict']]]]] = None,
                 sections: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DashboardSectionArgs', 'DashboardSectionArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DashboardArgs.__new__(DashboardArgs)

            __props__.__dict__["can_modifies"] = can_modifies
            __props__.__dict__["can_views"] = can_views
            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            __props__.__dict__["display_query_parameters"] = display_query_parameters
            __props__.__dict__["display_section_table_of_contents"] = display_section_table_of_contents
            __props__.__dict__["event_filter_type"] = event_filter_type
            __props__.__dict__["name"] = name
            __props__.__dict__["parameter_details"] = parameter_details
            if sections is None and not opts.urn:
                raise TypeError("Missing required property 'sections'")
            __props__.__dict__["sections"] = sections
            if tags is None and not opts.urn:
                raise TypeError("Missing required property 'tags'")
            __props__.__dict__["tags"] = tags
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
        super(Dashboard, __self__).__init__(
            'wavefront:index/dashboard:Dashboard',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            can_modifies: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            can_views: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            display_query_parameters: Optional[pulumi.Input[_builtins.bool]] = None,
            display_section_table_of_contents: Optional[pulumi.Input[_builtins.bool]] = None,
            event_filter_type: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            parameter_details: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DashboardParameterDetailArgs', 'DashboardParameterDetailArgsDict']]]]] = None,
            sections: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DashboardSectionArgs', 'DashboardSectionArgsDict']]]]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            url: Optional[pulumi.Input[_builtins.str]] = None) -> 'Dashboard':
        """
        Get an existing Dashboard resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] can_modifies: A list of users/groups/roles that can modify the dashboard.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] can_views: A list of users/groups/roles that can view the dashboard.
        :param pulumi.Input[_builtins.str] description: Human-readable description of the dashboard.
        :param pulumi.Input[_builtins.bool] display_query_parameters: Whether the dashboard parameters section is opened by default when the dashboard
               is shown.
        :param pulumi.Input[_builtins.bool] display_section_table_of_contents: Whether the "pills" quick-linked the sections of the dashboard are
               displayed by default when the dashboard is shown.
        :param pulumi.Input[_builtins.str] event_filter_type: How charts belonging to this dashboard should display events. `BYCHART` is default if
               unspecified. Valid options are: `BYCHART`, `AUTOMATIC`, `ALL`, `NONE`, `BYDASHBOARD`, and `BYCHARTANDDASHBOARD`.
        :param pulumi.Input[_builtins.str] name: Name of the dashboard.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DashboardParameterDetailArgs', 'DashboardParameterDetailArgsDict']]]] parameter_details: The current JSON representation of dashboard parameters. See parameter details.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DashboardSectionArgs', 'DashboardSectionArgsDict']]]] sections: Dashboard chart sections. See dashboard sections.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A set of tags to assign to this resource.
        :param pulumi.Input[_builtins.str] url: Unique identifier, also a URL slug of the dashboard.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DashboardState.__new__(_DashboardState)

        __props__.__dict__["can_modifies"] = can_modifies
        __props__.__dict__["can_views"] = can_views
        __props__.__dict__["description"] = description
        __props__.__dict__["display_query_parameters"] = display_query_parameters
        __props__.__dict__["display_section_table_of_contents"] = display_section_table_of_contents
        __props__.__dict__["event_filter_type"] = event_filter_type
        __props__.__dict__["name"] = name
        __props__.__dict__["parameter_details"] = parameter_details
        __props__.__dict__["sections"] = sections
        __props__.__dict__["tags"] = tags
        __props__.__dict__["url"] = url
        return Dashboard(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="canModifies")
    def can_modifies(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        A list of users/groups/roles that can modify the dashboard.
        """
        return pulumi.get(self, "can_modifies")

    @_builtins.property
    @pulumi.getter(name="canViews")
    def can_views(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        A list of users/groups/roles that can view the dashboard.
        """
        return pulumi.get(self, "can_views")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[_builtins.str]:
        """
        Human-readable description of the dashboard.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="displayQueryParameters")
    def display_query_parameters(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether the dashboard parameters section is opened by default when the dashboard
        is shown.
        """
        return pulumi.get(self, "display_query_parameters")

    @_builtins.property
    @pulumi.getter(name="displaySectionTableOfContents")
    def display_section_table_of_contents(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether the "pills" quick-linked the sections of the dashboard are
        displayed by default when the dashboard is shown.
        """
        return pulumi.get(self, "display_section_table_of_contents")

    @_builtins.property
    @pulumi.getter(name="eventFilterType")
    def event_filter_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        How charts belonging to this dashboard should display events. `BYCHART` is default if
        unspecified. Valid options are: `BYCHART`, `AUTOMATIC`, `ALL`, `NONE`, `BYDASHBOARD`, and `BYCHARTANDDASHBOARD`.
        """
        return pulumi.get(self, "event_filter_type")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the dashboard.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="parameterDetails")
    def parameter_details(self) -> pulumi.Output[Optional[Sequence['outputs.DashboardParameterDetail']]]:
        """
        The current JSON representation of dashboard parameters. See parameter details.
        """
        return pulumi.get(self, "parameter_details")

    @_builtins.property
    @pulumi.getter
    def sections(self) -> pulumi.Output[Sequence['outputs.DashboardSection']]:
        """
        Dashboard chart sections. See dashboard sections.
        """
        return pulumi.get(self, "sections")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        A set of tags to assign to this resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier, also a URL slug of the dashboard.
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetAlertResult',
    'AwaitableGetAlertResult',
    'get_alert',
    'get_alert_output',
]

@pulumi.output_type
class GetAlertResult:
    """
    A collection of values returned by getAlert.
    """
    def __init__(__self__, additional_information=None, alert_triage_dashboards=None, alert_type=None, can_modifies=None, can_views=None, condition=None, conditions=None, display_expression=None, evaluate_realtime_data=None, failing_host_label_pairs=None, id=None, in_maintenance_host_label_pairs=None, include_obsolete_metrics=None, minutes=None, name=None, notification_resend_frequency_minutes=None, process_rate_minutes=None, resolve_after_minutes=None, runbook_links=None, severity=None, severity_lists=None, statuses=None, tags=None, target=None, targets=None):
        if additional_information and not isinstance(additional_information, str):
            raise TypeError("Expected argument 'additional_information' to be a str")
        pulumi.set(__self__, "additional_information", additional_information)
        if alert_triage_dashboards and not isinstance(alert_triage_dashboards, list):
            raise TypeError("Expected argument 'alert_triage_dashboards' to be a list")
        pulumi.set(__self__, "alert_triage_dashboards", alert_triage_dashboards)
        if alert_type and not isinstance(alert_type, str):
            raise TypeError("Expected argument 'alert_type' to be a str")
        pulumi.set(__self__, "alert_type", alert_type)
        if can_modifies and not isinstance(can_modifies, list):
            raise TypeError("Expected argument 'can_modifies' to be a list")
        pulumi.set(__self__, "can_modifies", can_modifies)
        if can_views and not isinstance(can_views, list):
            raise TypeError("Expected argument 'can_views' to be a list")
        pulumi.set(__self__, "can_views", can_views)
        if condition and not isinstance(condition, str):
            raise TypeError("Expected argument 'condition' to be a str")
        pulumi.set(__self__, "condition", condition)
        if conditions and not isinstance(conditions, dict):
            raise TypeError("Expected argument 'conditions' to be a dict")
        pulumi.set(__self__, "conditions", conditions)
        if display_expression and not isinstance(display_expression, str):
            raise TypeError("Expected argument 'display_expression' to be a str")
        pulumi.set(__self__, "display_expression", display_expression)
        if evaluate_realtime_data and not isinstance(evaluate_realtime_data, bool):
            raise TypeError("Expected argument 'evaluate_realtime_data' to be a bool")
        pulumi.set(__self__, "evaluate_realtime_data", evaluate_realtime_data)
        if failing_host_label_pairs and not isinstance(failing_host_label_pairs, list):
            raise TypeError("Expected argument 'failing_host_label_pairs' to be a list")
        pulumi.set(__self__, "failing_host_label_pairs", failing_host_label_pairs)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if in_maintenance_host_label_pairs and not isinstance(in_maintenance_host_label_pairs, list):
            raise TypeError("Expected argument 'in_maintenance_host_label_pairs' to be a list")
        pulumi.set(__self__, "in_maintenance_host_label_pairs", in_maintenance_host_label_pairs)
        if include_obsolete_metrics and not isinstance(include_obsolete_metrics, bool):
            raise TypeError("Expected argument 'include_obsolete_metrics' to be a bool")
        pulumi.set(__self__, "include_obsolete_metrics", include_obsolete_metrics)
        if minutes and not isinstance(minutes, int):
            raise TypeError("Expected argument 'minutes' to be a int")
        pulumi.set(__self__, "minutes", minutes)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if notification_resend_frequency_minutes and not isinstance(notification_resend_frequency_minutes, int):
            raise TypeError("Expected argument 'notification_resend_frequency_minutes' to be a int")
        pulumi.set(__self__, "notification_resend_frequency_minutes", notification_resend_frequency_minutes)
        if process_rate_minutes and not isinstance(process_rate_minutes, int):
            raise TypeError("Expected argument 'process_rate_minutes' to be a int")
        pulumi.set(__self__, "process_rate_minutes", process_rate_minutes)
        if resolve_after_minutes and not isinstance(resolve_after_minutes, int):
            raise TypeError("Expected argument 'resolve_after_minutes' to be a int")
        pulumi.set(__self__, "resolve_after_minutes", resolve_after_minutes)
        if runbook_links and not isinstance(runbook_links, list):
            raise TypeError("Expected argument 'runbook_links' to be a list")
        pulumi.set(__self__, "runbook_links", runbook_links)
        if severity and not isinstance(severity, str):
            raise TypeError("Expected argument 'severity' to be a str")
        pulumi.set(__self__, "severity", severity)
        if severity_lists and not isinstance(severity_lists, list):
            raise TypeError("Expected argument 'severity_lists' to be a list")
        pulumi.set(__self__, "severity_lists", severity_lists)
        if statuses and not isinstance(statuses, list):
            raise TypeError("Expected argument 'statuses' to be a list")
        pulumi.set(__self__, "statuses", statuses)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if target and not isinstance(target, str):
            raise TypeError("Expected argument 'target' to be a str")
        pulumi.set(__self__, "target", target)
        if targets and not isinstance(targets, dict):
            raise TypeError("Expected argument 'targets' to be a dict")
        pulumi.set(__self__, "targets", targets)

    @_builtins.property
    @pulumi.getter(name="additionalInformation")
    def additional_information(self) -> _builtins.str:
        """
        User-supplied additional explanatory information about this alert.
        """
        return pulumi.get(self, "additional_information")

    @_builtins.property
    @pulumi.getter(name="alertTriageDashboards")
    def alert_triage_dashboards(self) -> Sequence['outputs.GetAlertAlertTriageDashboardResult']:
        """
        A set of user-supplied dashboard and parameters to create dashboard links for triaging alerts.
        """
        return pulumi.get(self, "alert_triage_dashboards")

    @_builtins.property
    @pulumi.getter(name="alertType")
    def alert_type(self) -> _builtins.str:
        """
        The type of alert in Wavefront.
        """
        return pulumi.get(self, "alert_type")

    @_builtins.property
    @pulumi.getter(name="canModifies")
    def can_modifies(self) -> Sequence[_builtins.str]:
        """
        A list of users or groups that can modify the alert.
        """
        return pulumi.get(self, "can_modifies")

    @_builtins.property
    @pulumi.getter(name="canViews")
    def can_views(self) -> Sequence[_builtins.str]:
        """
        A list of users or groups that can view the alert.
        """
        return pulumi.get(self, "can_views")

    @_builtins.property
    @pulumi.getter
    def condition(self) -> _builtins.str:
        """
        A Wavefront query that is evaluated at regular intervals (default is 1 minute). The alert fires and notifications are triggered when a data series matching this query evaluates to a non-zero value for a set number of consecutive minutes.
        """
        return pulumi.get(self, "condition")

    @_builtins.property
    @pulumi.getter
    def conditions(self) -> Mapping[str, _builtins.str]:
        """
        A map of severity to condition for which this alert will trigger.
        """
        return pulumi.get(self, "conditions")

    @_builtins.property
    @pulumi.getter(name="displayExpression")
    def display_expression(self) -> _builtins.str:
        """
        A second query the results of which are displayed in the alert user interface instead of the condition query.
        """
        return pulumi.get(self, "display_expression")

    @_builtins.property
    @pulumi.getter(name="evaluateRealtimeData")
    def evaluate_realtime_data(self) -> _builtins.bool:
        """
        A Boolean flag to enable real-time evaluation.
        """
        return pulumi.get(self, "evaluate_realtime_data")

    @_builtins.property
    @pulumi.getter(name="failingHostLabelPairs")
    def failing_host_label_pairs(self) -> Sequence['outputs.GetAlertFailingHostLabelPairResult']:
        """
        A list of failing host label pairs.
        """
        return pulumi.get(self, "failing_host_label_pairs")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the alert in Wavefront.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="inMaintenanceHostLabelPairs")
    def in_maintenance_host_label_pairs(self) -> Sequence['outputs.GetAlertInMaintenanceHostLabelPairResult']:
        """
        A list of in maintenance host label pairs.
        """
        return pulumi.get(self, "in_maintenance_host_label_pairs")

    @_builtins.property
    @pulumi.getter(name="includeObsoleteMetrics")
    def include_obsolete_metrics(self) -> _builtins.bool:
        """
        A Boolean flag indicating whether to include obsolete metrics or not.
        """
        return pulumi.get(self, "include_obsolete_metrics")

    @_builtins.property
    @pulumi.getter
    def minutes(self) -> _builtins.int:
        """
        The number of consecutive minutes that a series matching the condition query must evaluate to "true" (non-zero value) before the alert fires.
        """
        return pulumi.get(self, "minutes")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the alert as it is displayed in Wavefront.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="notificationResendFrequencyMinutes")
    def notification_resend_frequency_minutes(self) -> _builtins.int:
        """
        How often to re-trigger a continually failing alert.
        """
        return pulumi.get(self, "notification_resend_frequency_minutes")

    @_builtins.property
    @pulumi.getter(name="processRateMinutes")
    def process_rate_minutes(self) -> _builtins.int:
        """
        The specified query is executed every `process_rate_minutes` minutes.
        """
        return pulumi.get(self, "process_rate_minutes")

    @_builtins.property
    @pulumi.getter(name="resolveAfterMinutes")
    def resolve_after_minutes(self) -> _builtins.int:
        """
        The number of consecutive minutes that a firing series matching the condition query must evaluate to "false" (zero value) before the alert resolves.
        """
        return pulumi.get(self, "resolve_after_minutes")

    @_builtins.property
    @pulumi.getter(name="runbookLinks")
    def runbook_links(self) -> Sequence[_builtins.str]:
        """
        A list of user-supplied runbook links for this alert.
        """
        return pulumi.get(self, "runbook_links")

    @_builtins.property
    @pulumi.getter
    def severity(self) -> _builtins.str:
        """
        The severity of the alert.
        """
        return pulumi.get(self, "severity")

    @_builtins.property
    @pulumi.getter(name="severityLists")
    def severity_lists(self) -> Sequence[_builtins.str]:
        return pulumi.get(self, "severity_lists")

    @_builtins.property
    @pulumi.getter
    def statuses(self) -> Sequence[_builtins.str]:
        """
        The status of the alert.
        """
        return pulumi.get(self, "statuses")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        A set of tags assigned to the alert.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def target(self) -> _builtins.str:
        """
        An email address or integration endpoint (such as PagerDuty or webhook) to notify when the alert status changes.
        """
        return pulumi.get(self, "target")

    @_builtins.property
    @pulumi.getter
    def targets(self) -> Optional[Mapping[str, _builtins.str]]:
        """
        A comma-separated list of the email addresses or integration endpoints (such as PagerDuty or webhook) to notify when the alert status changes. Multiple target types can be in the list.
        """
        return pulumi.get(self, "targets")


class AwaitableGetAlertResult(GetAlertResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAlertResult(
            additional_information=self.additional_information,
            alert_triage_dashboards=self.alert_triage_dashboards,
            alert_type=self.alert_type,
            can_modifies=self.can_modifies,
            can_views=self.can_views,
            condition=self.condition,
            conditions=self.conditions,
            display_expression=self.display_expression,
            evaluate_realtime_data=self.evaluate_realtime_data,
            failing_host_label_pairs=self.failing_host_label_pairs,
            id=self.id,
            in_maintenance_host_label_pairs=self.in_maintenance_host_label_pairs,
            include_obsolete_metrics=self.include_obsolete_metrics,
            minutes=self.minutes,
            name=self.name,
            notification_resend_frequency_minutes=self.notification_resend_frequency_minutes,
            process_rate_minutes=self.process_rate_minutes,
            resolve_after_minutes=self.resolve_after_minutes,
            runbook_links=self.runbook_links,
            severity=self.severity,
            severity_lists=self.severity_lists,
            statuses=self.statuses,
            tags=self.tags,
            target=self.target,
            targets=self.targets)


def get_alert(id: Optional[_builtins.str] = None,
              targets: Optional[Mapping[str, _builtins.str]] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAlertResult:
    """
    Use this data source to get information about a Wavefront alert by its ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get the information about the alert.
    example = wavefront.get_alert(id="alert-id")
    ```


    :param _builtins.str id: The ID associated with the alert data to be fetched.
    :param Mapping[str, _builtins.str] targets: A comma-separated list of the email addresses or integration endpoints (such as PagerDuty or webhook) to notify when the alert status changes. Multiple target types can be in the list.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['targets'] = targets
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('wavefront:index/getAlert:getAlert', __args__, opts=opts, typ=GetAlertResult).value

    return AwaitableGetAlertResult(
        additional_information=pulumi.get(__ret__, 'additional_information'),
        alert_triage_dashboards=pulumi.get(__ret__, 'alert_triage_dashboards'),
        alert_type=pulumi.get(__ret__, 'alert_type'),
        can_modifies=pulumi.get(__ret__, 'can_modifies'),
        can_views=pulumi.get(__ret__, 'can_views'),
        condition=pulumi.get(__ret__, 'condition'),
        conditions=pulumi.get(__ret__, 'conditions'),
        display_expression=pulumi.get(__ret__, 'display_expression'),
        evaluate_realtime_data=pulumi.get(__ret__, 'evaluate_realtime_data'),
        failing_host_label_pairs=pulumi.get(__ret__, 'failing_host_label_pairs'),
        id=pulumi.get(__ret__, 'id'),
        in_maintenance_host_label_pairs=pulumi.get(__ret__, 'in_maintenance_host_label_pairs'),
        include_obsolete_metrics=pulumi.get(__ret__, 'include_obsolete_metrics'),
        minutes=pulumi.get(__ret__, 'minutes'),
        name=pulumi.get(__ret__, 'name'),
        notification_resend_frequency_minutes=pulumi.get(__ret__, 'notification_resend_frequency_minutes'),
        process_rate_minutes=pulumi.get(__ret__, 'process_rate_minutes'),
        resolve_after_minutes=pulumi.get(__ret__, 'resolve_after_minutes'),
        runbook_links=pulumi.get(__ret__, 'runbook_links'),
        severity=pulumi.get(__ret__, 'severity'),
        severity_lists=pulumi.get(__ret__, 'severity_lists'),
        statuses=pulumi.get(__ret__, 'statuses'),
        tags=pulumi.get(__ret__, 'tags'),
        target=pulumi.get(__ret__, 'target'),
        targets=pulumi.get(__ret__, 'targets'))
def get_alert_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                     targets: Optional[pulumi.Input[Optional[Mapping[str, _builtins.str]]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAlertResult]:
    """
    Use this data source to get information about a Wavefront alert by its ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get the information about the alert.
    example = wavefront.get_alert(id="alert-id")
    ```


    :param _builtins.str id: The ID associated with the alert data to be fetched.
    :param Mapping[str, _builtins.str] targets: A comma-separated list of the email addresses or integration endpoints (such as PagerDuty or webhook) to notify when the alert status changes. Multiple target types can be in the list.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['targets'] = targets
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('wavefront:index/getAlert:getAlert', __args__, opts=opts, typ=GetAlertResult)
    return __ret__.apply(lambda __response__: GetAlertResult(
        additional_information=pulumi.get(__response__, 'additional_information'),
        alert_triage_dashboards=pulumi.get(__response__, 'alert_triage_dashboards'),
        alert_type=pulumi.get(__response__, 'alert_type'),
        can_modifies=pulumi.get(__response__, 'can_modifies'),
        can_views=pulumi.get(__response__, 'can_views'),
        condition=pulumi.get(__response__, 'condition'),
        conditions=pulumi.get(__response__, 'conditions'),
        display_expression=pulumi.get(__response__, 'display_expression'),
        evaluate_realtime_data=pulumi.get(__response__, 'evaluate_realtime_data'),
        failing_host_label_pairs=pulumi.get(__response__, 'failing_host_label_pairs'),
        id=pulumi.get(__response__, 'id'),
        in_maintenance_host_label_pairs=pulumi.get(__response__, 'in_maintenance_host_label_pairs'),
        include_obsolete_metrics=pulumi.get(__response__, 'include_obsolete_metrics'),
        minutes=pulumi.get(__response__, 'minutes'),
        name=pulumi.get(__response__, 'name'),
        notification_resend_frequency_minutes=pulumi.get(__response__, 'notification_resend_frequency_minutes'),
        process_rate_minutes=pulumi.get(__response__, 'process_rate_minutes'),
        resolve_after_minutes=pulumi.get(__response__, 'resolve_after_minutes'),
        runbook_links=pulumi.get(__response__, 'runbook_links'),
        severity=pulumi.get(__response__, 'severity'),
        severity_lists=pulumi.get(__response__, 'severity_lists'),
        statuses=pulumi.get(__response__, 'statuses'),
        tags=pulumi.get(__response__, 'tags'),
        target=pulumi.get(__response__, 'target'),
        targets=pulumi.get(__response__, 'targets')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetDefaultUserGroupResult',
    'AwaitableGetDefaultUserGroupResult',
    'get_default_user_group',
    'get_default_user_group_output',
]

@pulumi.output_type
class GetDefaultUserGroupResult:
    """
    A collection of values returned by getDefaultUserGroup.
    """
    def __init__(__self__, group_id=None, id=None):
        if group_id and not isinstance(group_id, str):
            raise TypeError("Expected argument 'group_id' to be a str")
        pulumi.set(__self__, "group_id", group_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @_builtins.property
    @pulumi.getter(name="groupId")
    def group_id(self) -> _builtins.str:
        """
        Set to the Group ID of the `Everyone` group, suitable for referencing
        in other resources that support group memberships.
        """
        return pulumi.get(self, "group_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetDefaultUserGroupResult(GetDefaultUserGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDefaultUserGroupResult(
            group_id=self.group_id,
            id=self.id)


def get_default_user_group(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDefaultUserGroupResult:
    """
    Use this data source to get the Group ID of the `Everyone` group in Wavefront.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get the default user group "Everyone"
    everyone_group = wavefront.get_default_user_group()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('wavefront:index/getDefaultUserGroup:getDefaultUserGroup', __args__, opts=opts, typ=GetDefaultUserGroupResult).value

    return AwaitableGetDefaultUserGroupResult(
        group_id=pulumi.get(__ret__, 'group_id'),
        id=pulumi.get(__ret__, 'id'))
def get_default_user_group_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDefaultUserGroupResult]:
    """
    Use this data source to get the Group ID of the `Everyone` group in Wavefront.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get the default user group "Everyone"
    everyone_group = wavefront.get_default_user_group()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('wavefront:index/getDefaultUserGroup:getDefaultUserGroup', __args__, opts=opts, typ=GetDefaultUserGroupResult)
    return __ret__.apply(lambda __response__: GetDefaultUserGroupResult(
        group_id=pulumi.get(__response__, 'group_id'),
        id=pulumi.get(__response__, 'id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetAlertsResult',
    'AwaitableGetAlertsResult',
    'get_alerts',
    'get_alerts_output',
]

@pulumi.output_type
class GetAlertsResult:
    """
    A collection of values returned by getAlerts.
    """
    def __init__(__self__, alerts=None, id=None, limit=None, offset=None):
        if alerts and not isinstance(alerts, list):
            raise TypeError("Expected argument 'alerts' to be a list")
        pulumi.set(__self__, "alerts", alerts)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if limit and not isinstance(limit, int):
            raise TypeError("Expected argument 'limit' to be a int")
        pulumi.set(__self__, "limit", limit)
        if offset and not isinstance(offset, int):
            raise TypeError("Expected argument 'offset' to be a int")
        pulumi.set(__self__, "offset", offset)

    @_builtins.property
    @pulumi.getter
    def alerts(self) -> Sequence['outputs.GetAlertsAlertResult']:
        """
        List of all alerts in Wavefront. For each alert you will see a list of attributes.
        """
        return pulumi.get(self, "alerts")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def limit(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "limit")

    @_builtins.property
    @pulumi.getter
    def offset(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "offset")


class AwaitableGetAlertsResult(GetAlertsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAlertsResult(
            alerts=self.alerts,
            id=self.id,
            limit=self.limit,
            offset=self.offset)


def get_alerts(limit: Optional[_builtins.int] = None,
               offset: Optional[_builtins.int] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAlertsResult:
    """
    Use this data source to get information about all Wavefront alerts.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get the information about all alerts.
    example = wavefront.get_alerts(limit=10,
        offset=0)
    ```


    :param _builtins.int limit: Limit is the maximum number of results to be returned. Defaults to 100.
    :param _builtins.int offset: Offset is the offset from the first result to be returned. Defaults to 0.
    """
    __args__ = dict()
    __args__['limit'] = limit
    __args__['offset'] = offset
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('wavefront:index/getAlerts:getAlerts', __args__, opts=opts, typ=GetAlertsResult).value

    return AwaitableGetAlertsResult(
        alerts=pulumi.get(__ret__, 'alerts'),
        id=pulumi.get(__ret__, 'id'),
        limit=pulumi.get(__ret__, 'limit'),
        offset=pulumi.get(__ret__, 'offset'))
def get_alerts_output(limit: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                      offset: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAlertsResult]:
    """
    Use this data source to get information about all Wavefront alerts.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get the information about all alerts.
    example = wavefront.get_alerts(limit=10,
        offset=0)
    ```


    :param _builtins.int limit: Limit is the maximum number of results to be returned. Defaults to 100.
    :param _builtins.int offset: Offset is the offset from the first result to be returned. Defaults to 0.
    """
    __args__ = dict()
    __args__['limit'] = limit
    __args__['offset'] = offset
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('wavefront:index/getAlerts:getAlerts', __args__, opts=opts, typ=GetAlertsResult)
    return __ret__.apply(lambda __response__: GetAlertsResult(
        alerts=pulumi.get(__response__, 'alerts'),
        id=pulumi.get(__response__, 'id'),
        limit=pulumi.get(__response__, 'limit'),
        offset=pulumi.get(__response__, 'offset')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetDerivedMetricResult',
    'AwaitableGetDerivedMetricResult',
    'get_derived_metric',
    'get_derived_metric_output',
]

@pulumi.output_type
class GetDerivedMetricResult:
    """
    A collection of values returned by getDerivedMetric.
    """
    def __init__(__self__, additional_information=None, create_user_id=None, created_epoch_millis=None, deleted=None, hosts_useds=None, id=None, in_trash=None, include_obsolete_metrics=None, last_error_message=None, last_failed_time=None, last_processed_millis=None, last_query_time=None, metrics_useds=None, minutes=None, name=None, points_scanned_at_last_query=None, process_rate_minutes=None, query=None, query_failing=None, query_qb_enabled=None, statuses=None, tags=None, update_user_id=None, updated_epoch_millis=None):
        if additional_information and not isinstance(additional_information, str):
            raise TypeError("Expected argument 'additional_information' to be a str")
        pulumi.set(__self__, "additional_information", additional_information)
        if create_user_id and not isinstance(create_user_id, str):
            raise TypeError("Expected argument 'create_user_id' to be a str")
        pulumi.set(__self__, "create_user_id", create_user_id)
        if created_epoch_millis and not isinstance(created_epoch_millis, int):
            raise TypeError("Expected argument 'created_epoch_millis' to be a int")
        pulumi.set(__self__, "created_epoch_millis", created_epoch_millis)
        if deleted and not isinstance(deleted, bool):
            raise TypeError("Expected argument 'deleted' to be a bool")
        pulumi.set(__self__, "deleted", deleted)
        if hosts_useds and not isinstance(hosts_useds, list):
            raise TypeError("Expected argument 'hosts_useds' to be a list")
        pulumi.set(__self__, "hosts_useds", hosts_useds)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if in_trash and not isinstance(in_trash, bool):
            raise TypeError("Expected argument 'in_trash' to be a bool")
        pulumi.set(__self__, "in_trash", in_trash)
        if include_obsolete_metrics and not isinstance(include_obsolete_metrics, bool):
            raise TypeError("Expected argument 'include_obsolete_metrics' to be a bool")
        pulumi.set(__self__, "include_obsolete_metrics", include_obsolete_metrics)
        if last_error_message and not isinstance(last_error_message, str):
            raise TypeError("Expected argument 'last_error_message' to be a str")
        pulumi.set(__self__, "last_error_message", last_error_message)
        if last_failed_time and not isinstance(last_failed_time, int):
            raise TypeError("Expected argument 'last_failed_time' to be a int")
        pulumi.set(__self__, "last_failed_time", last_failed_time)
        if last_processed_millis and not isinstance(last_processed_millis, int):
            raise TypeError("Expected argument 'last_processed_millis' to be a int")
        pulumi.set(__self__, "last_processed_millis", last_processed_millis)
        if last_query_time and not isinstance(last_query_time, int):
            raise TypeError("Expected argument 'last_query_time' to be a int")
        pulumi.set(__self__, "last_query_time", last_query_time)
        if metrics_useds and not isinstance(metrics_useds, list):
            raise TypeError("Expected argument 'metrics_useds' to be a list")
        pulumi.set(__self__, "metrics_useds", metrics_useds)
        if minutes and not isinstance(minutes, int):
            raise TypeError("Expected argument 'minutes' to be a int")
        pulumi.set(__self__, "minutes", minutes)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if points_scanned_at_last_query and not isinstance(points_scanned_at_last_query, int):
            raise TypeError("Expected argument 'points_scanned_at_last_query' to be a int")
        pulumi.set(__self__, "points_scanned_at_last_query", points_scanned_at_last_query)
        if process_rate_minutes and not isinstance(process_rate_minutes, int):
            raise TypeError("Expected argument 'process_rate_minutes' to be a int")
        pulumi.set(__self__, "process_rate_minutes", process_rate_minutes)
        if query and not isinstance(query, str):
            raise TypeError("Expected argument 'query' to be a str")
        pulumi.set(__self__, "query", query)
        if query_failing and not isinstance(query_failing, bool):
            raise TypeError("Expected argument 'query_failing' to be a bool")
        pulumi.set(__self__, "query_failing", query_failing)
        if query_qb_enabled and not isinstance(query_qb_enabled, bool):
            raise TypeError("Expected argument 'query_qb_enabled' to be a bool")
        pulumi.set(__self__, "query_qb_enabled", query_qb_enabled)
        if statuses and not isinstance(statuses, list):
            raise TypeError("Expected argument 'statuses' to be a list")
        pulumi.set(__self__, "statuses", statuses)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if update_user_id and not isinstance(update_user_id, str):
            raise TypeError("Expected argument 'update_user_id' to be a str")
        pulumi.set(__self__, "update_user_id", update_user_id)
        if updated_epoch_millis and not isinstance(updated_epoch_millis, int):
            raise TypeError("Expected argument 'updated_epoch_millis' to be a int")
        pulumi.set(__self__, "updated_epoch_millis", updated_epoch_millis)

    @_builtins.property
    @pulumi.getter(name="additionalInformation")
    def additional_information(self) -> _builtins.str:
        """
        User-supplied additional explanatory information about the derived metric.
        """
        return pulumi.get(self, "additional_information")

    @_builtins.property
    @pulumi.getter(name="createUserId")
    def create_user_id(self) -> _builtins.str:
        """
        The ID of the user who created the derived metric.
        """
        return pulumi.get(self, "create_user_id")

    @_builtins.property
    @pulumi.getter(name="createdEpochMillis")
    def created_epoch_millis(self) -> _builtins.int:
        """
        The timestamp in epoch milliseconds indicating when the derived metric is created.
        """
        return pulumi.get(self, "created_epoch_millis")

    @_builtins.property
    @pulumi.getter
    def deleted(self) -> _builtins.bool:
        """
        A Boolean flag indicating whether the derived metric is deleted or not.
        """
        return pulumi.get(self, "deleted")

    @_builtins.property
    @pulumi.getter(name="hostsUseds")
    def hosts_useds(self) -> Sequence[_builtins.str]:
        """
        A list of hosts used in the derived metric.
        """
        return pulumi.get(self, "hosts_useds")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the derived metric in Wavefront.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="inTrash")
    def in_trash(self) -> _builtins.bool:
        """
        A Boolean variable indicating trash status.
        """
        return pulumi.get(self, "in_trash")

    @_builtins.property
    @pulumi.getter(name="includeObsoleteMetrics")
    def include_obsolete_metrics(self) -> _builtins.bool:
        """
        A Boolean flag indicating whether to include obsolete metrics or not.
        """
        return pulumi.get(self, "include_obsolete_metrics")

    @_builtins.property
    @pulumi.getter(name="lastErrorMessage")
    def last_error_message(self) -> _builtins.str:
        """
        Last error message occurred.
        """
        return pulumi.get(self, "last_error_message")

    @_builtins.property
    @pulumi.getter(name="lastFailedTime")
    def last_failed_time(self) -> _builtins.int:
        """
        Timestamp of the last failed derived metric.
        """
        return pulumi.get(self, "last_failed_time")

    @_builtins.property
    @pulumi.getter(name="lastProcessedMillis")
    def last_processed_millis(self) -> _builtins.int:
        """
        The last processed timestamp.
        """
        return pulumi.get(self, "last_processed_millis")

    @_builtins.property
    @pulumi.getter(name="lastQueryTime")
    def last_query_time(self) -> _builtins.int:
        """
        The timestamp indicating the last time the query was executed.
        """
        return pulumi.get(self, "last_query_time")

    @_builtins.property
    @pulumi.getter(name="metricsUseds")
    def metrics_useds(self) -> Sequence[_builtins.str]:
        """
        A list of metrics used in the derived metric.
        """
        return pulumi.get(self, "metrics_useds")

    @_builtins.property
    @pulumi.getter
    def minutes(self) -> _builtins.int:
        """
        How frequently the query generating the derived metric is run.
        """
        return pulumi.get(self, "minutes")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the derived metric in Wavefront.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="pointsScannedAtLastQuery")
    def points_scanned_at_last_query(self) -> _builtins.int:
        """
        The number of points scanned when last query was executed.
        """
        return pulumi.get(self, "points_scanned_at_last_query")

    @_builtins.property
    @pulumi.getter(name="processRateMinutes")
    def process_rate_minutes(self) -> _builtins.int:
        """
        The specified query is executed every `process_rate_minutes` minutes.
        """
        return pulumi.get(self, "process_rate_minutes")

    @_builtins.property
    @pulumi.getter
    def query(self) -> _builtins.str:
        """
        A Wavefront query that is evaluated at regular intervals (default is 1 minute).
        """
        return pulumi.get(self, "query")

    @_builtins.property
    @pulumi.getter(name="queryFailing")
    def query_failing(self) -> _builtins.bool:
        """
        A Boolean variable indicating whether query is failing for the derived metric.
        """
        return pulumi.get(self, "query_failing")

    @_builtins.property
    @pulumi.getter(name="queryQbEnabled")
    def query_qb_enabled(self) -> _builtins.bool:
        """
        A Boolean flag for enabling `query_qb`
        """
        return pulumi.get(self, "query_qb_enabled")

    @_builtins.property
    @pulumi.getter
    def statuses(self) -> Sequence[_builtins.str]:
        """
        The status of the derived metric.
        """
        return pulumi.get(self, "statuses")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        A set of tags assigned to the derived metric.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updateUserId")
    def update_user_id(self) -> _builtins.str:
        """
        The ID of the user who updated the derived metric.
        """
        return pulumi.get(self, "update_user_id")

    @_builtins.property
    @pulumi.getter(name="updatedEpochMillis")
    def updated_epoch_millis(self) -> _builtins.int:
        """
        The timestamp in epoch milliseconds indicating when the derived metric is updated.
        """
        return pulumi.get(self, "updated_epoch_millis")


class AwaitableGetDerivedMetricResult(GetDerivedMetricResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDerivedMetricResult(
            additional_information=self.additional_information,
            create_user_id=self.create_user_id,
            created_epoch_millis=self.created_epoch_millis,
            deleted=self.deleted,
            hosts_useds=self.hosts_useds,
            id=self.id,
            in_trash=self.in_trash,
            include_obsolete_metrics=self.include_obsolete_metrics,
            last_error_message=self.last_error_message,
            last_failed_time=self.last_failed_time,
            last_processed_millis=self.last_processed_millis,
            last_query_time=self.last_query_time,
            metrics_useds=self.metrics_useds,
            minutes=self.minutes,
            name=self.name,
            points_scanned_at_last_query=self.points_scanned_at_last_query,
            process_rate_minutes=self.process_rate_minutes,
            query=self.query,
            query_failing=self.query_failing,
            query_qb_enabled=self.query_qb_enabled,
            statuses=self.statuses,
            tags=self.tags,
            update_user_id=self.update_user_id,
            updated_epoch_millis=self.updated_epoch_millis)


def get_derived_metric(id: Optional[_builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDerivedMetricResult:
    """
    Use this data source to get information about a certain Wavefront derived metric by its ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    #Get the information about a derived metric.
    example = wavefront.get_derived_metric(id="derived_metric_id")
    ```


    :param _builtins.str id: The ID associated with the derived metric data to be fetched.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('wavefront:index/getDerivedMetric:getDerivedMetric', __args__, opts=opts, typ=GetDerivedMetricResult).value

    return AwaitableGetDerivedMetricResult(
        additional_information=pulumi.get(__ret__, 'additional_information'),
        create_user_id=pulumi.get(__ret__, 'create_user_id'),
        created_epoch_millis=pulumi.get(__ret__, 'created_epoch_millis'),
        deleted=pulumi.get(__ret__, 'deleted'),
        hosts_useds=pulumi.get(__ret__, 'hosts_useds'),
        id=pulumi.get(__ret__, 'id'),
        in_trash=pulumi.get(__ret__, 'in_trash'),
        include_obsolete_metrics=pulumi.get(__ret__, 'include_obsolete_metrics'),
        last_error_message=pulumi.get(__ret__, 'last_error_message'),
        last_failed_time=pulumi.get(__ret__, 'last_failed_time'),
        last_processed_millis=pulumi.get(__ret__, 'last_processed_millis'),
        last_query_time=pulumi.get(__ret__, 'last_query_time'),
        metrics_useds=pulumi.get(__ret__, 'metrics_useds'),
        minutes=pulumi.get(__ret__, 'minutes'),
        name=pulumi.get(__ret__, 'name'),
        points_scanned_at_last_query=pulumi.get(__ret__, 'points_scanned_at_last_query'),
        process_rate_minutes=pulumi.get(__ret__, 'process_rate_minutes'),
        query=pulumi.get(__ret__, 'query'),
        query_failing=pulumi.get(__ret__, 'query_failing'),
        query_qb_enabled=pulumi.get(__ret__, 'query_qb_enabled'),
        statuses=pulumi.get(__ret__, 'statuses'),
        tags=pulumi.get(__ret__, 'tags'),
        update_user_id=pulumi.get(__ret__, 'update_user_id'),
        updated_epoch_millis=pulumi.get(__ret__, 'updated_epoch_millis'))
def get_derived_metric_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDerivedMetricResult]:
    """
    Use this data source to get information about a certain Wavefront derived metric by its ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    #Get the information about a derived metric.
    example = wavefront.get_derived_metric(id="derived_metric_id")
    ```


    :param _builtins.str id: The ID associated with the derived metric data to be fetched.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('wavefront:index/getDerivedMetric:getDerivedMetric', __args__, opts=opts, typ=GetDerivedMetricResult)
    return __ret__.apply(lambda __response__: GetDerivedMetricResult(
        additional_information=pulumi.get(__response__, 'additional_information'),
        create_user_id=pulumi.get(__response__, 'create_user_id'),
        created_epoch_millis=pulumi.get(__response__, 'created_epoch_millis'),
        deleted=pulumi.get(__response__, 'deleted'),
        hosts_useds=pulumi.get(__response__, 'hosts_useds'),
        id=pulumi.get(__response__, 'id'),
        in_trash=pulumi.get(__response__, 'in_trash'),
        include_obsolete_metrics=pulumi.get(__response__, 'include_obsolete_metrics'),
        last_error_message=pulumi.get(__response__, 'last_error_message'),
        last_failed_time=pulumi.get(__response__, 'last_failed_time'),
        last_processed_millis=pulumi.get(__response__, 'last_processed_millis'),
        last_query_time=pulumi.get(__response__, 'last_query_time'),
        metrics_useds=pulumi.get(__response__, 'metrics_useds'),
        minutes=pulumi.get(__response__, 'minutes'),
        name=pulumi.get(__response__, 'name'),
        points_scanned_at_last_query=pulumi.get(__response__, 'points_scanned_at_last_query'),
        process_rate_minutes=pulumi.get(__response__, 'process_rate_minutes'),
        query=pulumi.get(__response__, 'query'),
        query_failing=pulumi.get(__response__, 'query_failing'),
        query_qb_enabled=pulumi.get(__response__, 'query_qb_enabled'),
        statuses=pulumi.get(__response__, 'statuses'),
        tags=pulumi.get(__response__, 'tags'),
        update_user_id=pulumi.get(__response__, 'update_user_id'),
        updated_epoch_millis=pulumi.get(__response__, 'updated_epoch_millis')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[_builtins.str],
                 customer: Optional[pulumi.Input[_builtins.str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a User resource.
        :param pulumi.Input[_builtins.str] email: The unique identifier of the user account to create. Must be a valid email address.
        :param pulumi.Input[_builtins.str] customer: The customer the user is associated with.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] permissions: List of permission to grant to this user. Valid options are
               `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
               `host_tag_management`, `metrics_management`, and `user_management`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_groups: List of user groups to this user.
        """
        pulumi.set(__self__, "email", email)
        if customer is not None:
            pulumi.set(__self__, "customer", customer)
        if permissions is not None:
            pulumi.set(__self__, "permissions", permissions)
        if user_groups is not None:
            pulumi.set(__self__, "user_groups", user_groups)

    @_builtins.property
    @pulumi.getter
    def email(self) -> pulumi.Input[_builtins.str]:
        """
        The unique identifier of the user account to create. Must be a valid email address.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "email", value)

    @_builtins.property
    @pulumi.getter
    def customer(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The customer the user is associated with.
        """
        return pulumi.get(self, "customer")

    @customer.setter
    def customer(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "customer", value)

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of permission to grant to this user. Valid options are
        `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
        `host_tag_management`, `metrics_management`, and `user_management`.
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "permissions", value)

    @_builtins.property
    @pulumi.getter(name="userGroups")
    def user_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of user groups to this user.
        """
        return pulumi.get(self, "user_groups")

    @user_groups.setter
    def user_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "user_groups", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 customer: Optional[pulumi.Input[_builtins.str]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering User resources.
        :param pulumi.Input[_builtins.str] customer: The customer the user is associated with.
        :param pulumi.Input[_builtins.str] email: The unique identifier of the user account to create. Must be a valid email address.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] permissions: List of permission to grant to this user. Valid options are
               `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
               `host_tag_management`, `metrics_management`, and `user_management`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_groups: List of user groups to this user.
        """
        if customer is not None:
            pulumi.set(__self__, "customer", customer)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if permissions is not None:
            pulumi.set(__self__, "permissions", permissions)
        if user_groups is not None:
            pulumi.set(__self__, "user_groups", user_groups)

    @_builtins.property
    @pulumi.getter
    def customer(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The customer the user is associated with.
        """
        return pulumi.get(self, "customer")

    @customer.setter
    def customer(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "customer", value)

    @_builtins.property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the user account to create. Must be a valid email address.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email", value)

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of permission to grant to this user. Valid options are
        `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
        `host_tag_management`, `metrics_management`, and `user_management`.
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "permissions", value)

    @_builtins.property
    @pulumi.getter(name="userGroups")
    def user_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of user groups to this user.
        """
        return pulumi.get(self, "user_groups")

    @user_groups.setter
    def user_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "user_groups", value)


@pulumi.type_token("wavefront:index/user:User")
class User(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 customer: Optional[pulumi.Input[_builtins.str]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Provides a Wavefront User Resource. This allows user accounts to be created, updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        basic = wavefront.User("basic", email="test+tftesting@example.com")
        ```

        ## Import

        Users can be imported by using the `id`, e.g.:

        ```sh
        $ pulumi import wavefront:index/user:User some_user test@example.com
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] customer: The customer the user is associated with.
        :param pulumi.Input[_builtins.str] email: The unique identifier of the user account to create. Must be a valid email address.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] permissions: List of permission to grant to this user. Valid options are
               `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
               `host_tag_management`, `metrics_management`, and `user_management`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_groups: List of user groups to this user.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Wavefront User Resource. This allows user accounts to be created, updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        basic = wavefront.User("basic", email="test+tftesting@example.com")
        ```

        ## Import

        Users can be imported by using the `id`, e.g.:

        ```sh
        $ pulumi import wavefront:index/user:User some_user test@example.com
        ```

        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 customer: Optional[pulumi.Input[_builtins.str]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            __props__.__dict__["customer"] = customer
            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__.__dict__["email"] = email
            __props__.__dict__["permissions"] = permissions
            __props__.__dict__["user_groups"] = user_groups
        super(User, __self__).__init__(
            'wavefront:index/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            customer: Optional[pulumi.Input[_builtins.str]] = None,
            email: Optional[pulumi.Input[_builtins.str]] = None,
            permissions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            user_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] customer: The customer the user is associated with.
        :param pulumi.Input[_builtins.str] email: The unique identifier of the user account to create. Must be a valid email address.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] permissions: List of permission to grant to this user. Valid options are
               `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
               `host_tag_management`, `metrics_management`, and `user_management`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_groups: List of user groups to this user.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["customer"] = customer
        __props__.__dict__["email"] = email
        __props__.__dict__["permissions"] = permissions
        __props__.__dict__["user_groups"] = user_groups
        return User(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def customer(self) -> pulumi.Output[_builtins.str]:
        """
        The customer the user is associated with.
        """
        return pulumi.get(self, "customer")

    @_builtins.property
    @pulumi.getter
    def email(self) -> pulumi.Output[_builtins.str]:
        """
        The unique identifier of the user account to create. Must be a valid email address.
        """
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        List of permission to grant to this user. Valid options are
        `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
        `host_tag_management`, `metrics_management`, and `user_management`.
        """
        return pulumi.get(self, "permissions")

    @_builtins.property
    @pulumi.getter(name="userGroups")
    def user_groups(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        List of user groups to this user.
        """
        return pulumi.get(self, "user_groups")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetRoleResult',
    'AwaitableGetRoleResult',
    'get_role',
    'get_role_output',
]

@pulumi.output_type
class GetRoleResult:
    """
    A collection of values returned by getRole.
    """
    def __init__(__self__, description=None, id=None, name=None, permissions=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if permissions and not isinstance(permissions, list):
            raise TypeError("Expected argument 'permissions' to be a list")
        pulumi.set(__self__, "permissions", permissions)

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Human-readable description of the role.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the role in Wavefront.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the role in Wavefront.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> Sequence[_builtins.str]:
        """
        The list of permissions associated with role.
        """
        return pulumi.get(self, "permissions")


class AwaitableGetRoleResult(GetRoleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRoleResult(
            description=self.description,
            id=self.id,
            name=self.name,
            permissions=self.permissions)


def get_role(id: Optional[_builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRoleResult:
    """
    Use this data source to get information about a Wavefront role by its ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get the information about the role.
    example = wavefront.get_role(id="role-id")
    ```


    :param _builtins.str id: The ID associated with the role data to be fetched.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('wavefront:index/getRole:getRole', __args__, opts=opts, typ=GetRoleResult).value

    return AwaitableGetRoleResult(
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        permissions=pulumi.get(__ret__, 'permissions'))
def get_role_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRoleResult]:
    """
    Use this data source to get information about a Wavefront role by its ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get the information about the role.
    example = wavefront.get_role(id="role-id")
    ```


    :param _builtins.str id: The ID associated with the role data to be fetched.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('wavefront:index/getRole:getRole', __args__, opts=opts, typ=GetRoleResult)
    return __ret__.apply(lambda __response__: GetRoleResult(
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        permissions=pulumi.get(__response__, 'permissions')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetMetricsPolicyResult',
    'AwaitableGetMetricsPolicyResult',
    'get_metrics_policy',
    'get_metrics_policy_output',
]

@pulumi.output_type
class GetMetricsPolicyResult:
    """
    A collection of values returned by getMetricsPolicy.
    """
    def __init__(__self__, customer=None, id=None, policy_rules=None, updated_epoch_millis=None, updater_id=None):
        if customer and not isinstance(customer, str):
            raise TypeError("Expected argument 'customer' to be a str")
        pulumi.set(__self__, "customer", customer)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if policy_rules and not isinstance(policy_rules, list):
            raise TypeError("Expected argument 'policy_rules' to be a list")
        pulumi.set(__self__, "policy_rules", policy_rules)
        if updated_epoch_millis and not isinstance(updated_epoch_millis, int):
            raise TypeError("Expected argument 'updated_epoch_millis' to be a int")
        pulumi.set(__self__, "updated_epoch_millis", updated_epoch_millis)
        if updater_id and not isinstance(updater_id, str):
            raise TypeError("Expected argument 'updater_id' to be a str")
        pulumi.set(__self__, "updater_id", updater_id)

    @_builtins.property
    @pulumi.getter
    def customer(self) -> _builtins.str:
        return pulumi.get(self, "customer")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="policyRules")
    def policy_rules(self) -> Sequence['outputs.GetMetricsPolicyPolicyRuleResult']:
        return pulumi.get(self, "policy_rules")

    @_builtins.property
    @pulumi.getter(name="updatedEpochMillis")
    def updated_epoch_millis(self) -> _builtins.int:
        return pulumi.get(self, "updated_epoch_millis")

    @_builtins.property
    @pulumi.getter(name="updaterId")
    def updater_id(self) -> _builtins.str:
        return pulumi.get(self, "updater_id")


class AwaitableGetMetricsPolicyResult(GetMetricsPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMetricsPolicyResult(
            customer=self.customer,
            id=self.id,
            policy_rules=self.policy_rules,
            updated_epoch_millis=self.updated_epoch_millis,
            updater_id=self.updater_id)


def get_metrics_policy(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMetricsPolicyResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('wavefront:index/getMetricsPolicy:getMetricsPolicy', __args__, opts=opts, typ=GetMetricsPolicyResult).value

    return AwaitableGetMetricsPolicyResult(
        customer=pulumi.get(__ret__, 'customer'),
        id=pulumi.get(__ret__, 'id'),
        policy_rules=pulumi.get(__ret__, 'policy_rules'),
        updated_epoch_millis=pulumi.get(__ret__, 'updated_epoch_millis'),
        updater_id=pulumi.get(__ret__, 'updater_id'))
def get_metrics_policy_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetMetricsPolicyResult]:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('wavefront:index/getMetricsPolicy:getMetricsPolicy', __args__, opts=opts, typ=GetMetricsPolicyResult)
    return __ret__.apply(lambda __response__: GetMetricsPolicyResult(
        customer=pulumi.get(__response__, 'customer'),
        id=pulumi.get(__response__, 'id'),
        policy_rules=pulumi.get(__response__, 'policy_rules'),
        updated_epoch_millis=pulumi.get(__response__, 'updated_epoch_millis'),
        updater_id=pulumi.get(__response__, 'updater_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetMaintenanceWindowResult',
    'AwaitableGetMaintenanceWindowResult',
    'get_maintenance_window',
    'get_maintenance_window_output',
]

@pulumi.output_type
class GetMaintenanceWindowResult:
    """
    A collection of values returned by getMaintenanceWindow.
    """
    def __init__(__self__, created_epoch_millis=None, creator_id=None, customer_id=None, end_time_in_seconds=None, event_name=None, host_tag_group_host_names_group_anded=None, id=None, reason=None, relevant_customer_tags=None, relevant_host_names=None, relevant_host_tags=None, relevant_host_tags_anded=None, running_state=None, sort_attr=None, start_time_in_seconds=None, title=None, updated_epoch_millis=None, updater_id=None):
        if created_epoch_millis and not isinstance(created_epoch_millis, int):
            raise TypeError("Expected argument 'created_epoch_millis' to be a int")
        pulumi.set(__self__, "created_epoch_millis", created_epoch_millis)
        if creator_id and not isinstance(creator_id, str):
            raise TypeError("Expected argument 'creator_id' to be a str")
        pulumi.set(__self__, "creator_id", creator_id)
        if customer_id and not isinstance(customer_id, str):
            raise TypeError("Expected argument 'customer_id' to be a str")
        pulumi.set(__self__, "customer_id", customer_id)
        if end_time_in_seconds and not isinstance(end_time_in_seconds, int):
            raise TypeError("Expected argument 'end_time_in_seconds' to be a int")
        pulumi.set(__self__, "end_time_in_seconds", end_time_in_seconds)
        if event_name and not isinstance(event_name, str):
            raise TypeError("Expected argument 'event_name' to be a str")
        pulumi.set(__self__, "event_name", event_name)
        if host_tag_group_host_names_group_anded and not isinstance(host_tag_group_host_names_group_anded, bool):
            raise TypeError("Expected argument 'host_tag_group_host_names_group_anded' to be a bool")
        pulumi.set(__self__, "host_tag_group_host_names_group_anded", host_tag_group_host_names_group_anded)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if reason and not isinstance(reason, str):
            raise TypeError("Expected argument 'reason' to be a str")
        pulumi.set(__self__, "reason", reason)
        if relevant_customer_tags and not isinstance(relevant_customer_tags, list):
            raise TypeError("Expected argument 'relevant_customer_tags' to be a list")
        pulumi.set(__self__, "relevant_customer_tags", relevant_customer_tags)
        if relevant_host_names and not isinstance(relevant_host_names, list):
            raise TypeError("Expected argument 'relevant_host_names' to be a list")
        pulumi.set(__self__, "relevant_host_names", relevant_host_names)
        if relevant_host_tags and not isinstance(relevant_host_tags, list):
            raise TypeError("Expected argument 'relevant_host_tags' to be a list")
        pulumi.set(__self__, "relevant_host_tags", relevant_host_tags)
        if relevant_host_tags_anded and not isinstance(relevant_host_tags_anded, bool):
            raise TypeError("Expected argument 'relevant_host_tags_anded' to be a bool")
        pulumi.set(__self__, "relevant_host_tags_anded", relevant_host_tags_anded)
        if running_state and not isinstance(running_state, str):
            raise TypeError("Expected argument 'running_state' to be a str")
        pulumi.set(__self__, "running_state", running_state)
        if sort_attr and not isinstance(sort_attr, int):
            raise TypeError("Expected argument 'sort_attr' to be a int")
        pulumi.set(__self__, "sort_attr", sort_attr)
        if start_time_in_seconds and not isinstance(start_time_in_seconds, int):
            raise TypeError("Expected argument 'start_time_in_seconds' to be a int")
        pulumi.set(__self__, "start_time_in_seconds", start_time_in_seconds)
        if title and not isinstance(title, str):
            raise TypeError("Expected argument 'title' to be a str")
        pulumi.set(__self__, "title", title)
        if updated_epoch_millis and not isinstance(updated_epoch_millis, int):
            raise TypeError("Expected argument 'updated_epoch_millis' to be a int")
        pulumi.set(__self__, "updated_epoch_millis", updated_epoch_millis)
        if updater_id and not isinstance(updater_id, str):
            raise TypeError("Expected argument 'updater_id' to be a str")
        pulumi.set(__self__, "updater_id", updater_id)

    @_builtins.property
    @pulumi.getter(name="createdEpochMillis")
    def created_epoch_millis(self) -> _builtins.int:
        """
        The timestamp in epoch milliseconds indicating when the maintenance window is created.
        """
        return pulumi.get(self, "created_epoch_millis")

    @_builtins.property
    @pulumi.getter(name="creatorId")
    def creator_id(self) -> _builtins.str:
        """
        The ID of the user who created the maintenance window.
        """
        return pulumi.get(self, "creator_id")

    @_builtins.property
    @pulumi.getter(name="customerId")
    def customer_id(self) -> _builtins.str:
        """
        The ID of the customer in Wavefront.
        """
        return pulumi.get(self, "customer_id")

    @_builtins.property
    @pulumi.getter(name="endTimeInSeconds")
    def end_time_in_seconds(self) -> _builtins.int:
        """
        The end time in seconds after 1 Jan 1970 GMT.
        """
        return pulumi.get(self, "end_time_in_seconds")

    @_builtins.property
    @pulumi.getter(name="eventName")
    def event_name(self) -> _builtins.str:
        """
        The event name of the maintenance window.
        """
        return pulumi.get(self, "event_name")

    @_builtins.property
    @pulumi.getter(name="hostTagGroupHostNamesGroupAnded")
    def host_tag_group_host_names_group_anded(self) -> _builtins.bool:
        """
        If set to `true`, the source or host must be in `relevant_host_names` and must have tags matching the specification formed by `relevant_host_tags` and `relevant_host_tags_anded` in for this maintenance window to apply.
        If set to false, the source or host must either be in `relevant_host_names` or match `relevant_host_tags` and `relevant_host_tags_anded`. Default value is `false`.
        """
        return pulumi.get(self, "host_tag_group_host_names_group_anded")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the maintenance window.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def reason(self) -> _builtins.str:
        """
        The reason for the maintenance window.
        """
        return pulumi.get(self, "reason")

    @_builtins.property
    @pulumi.getter(name="relevantCustomerTags")
    def relevant_customer_tags(self) -> Sequence[_builtins.str]:
        """
        The list of alert tags whose matching alerts will be put into maintenance because
        of this maintenance window. At least one of `relevant_customer_tags`, `relevant_host_tags`, or `relevant_host_names`
        is required.
        """
        return pulumi.get(self, "relevant_customer_tags")

    @_builtins.property
    @pulumi.getter(name="relevantHostNames")
    def relevant_host_names(self) -> Sequence[_builtins.str]:
        """
        The list of source or host names that will be put into maintenance because of this
        maintenance window. At least one of `relevant_customer_tags`, `relevant_host_tags`, or `relevant_host_names`
        is required.
        """
        return pulumi.get(self, "relevant_host_names")

    @_builtins.property
    @pulumi.getter(name="relevantHostTags")
    def relevant_host_tags(self) -> Sequence[_builtins.str]:
        """
        The list of source or host tags whose matching sources or hosts will be put into maintenance
        because of this maintenance window. At least one of `relevant_customer_tags`, `relevant_host_tags`, or
        `relevant_host_names` is required.
        """
        return pulumi.get(self, "relevant_host_tags")

    @_builtins.property
    @pulumi.getter(name="relevantHostTagsAnded")
    def relevant_host_tags_anded(self) -> _builtins.bool:
        """
        Whether to AND source or host tags listed in `relevant_host_tags`.
        If set to `true`, the source or host must contain all tags for the maintenance window to apply. If set to `false`,
        the tags are OR'ed, and the source or host must contain one of the tags. Default value is `false`.
        """
        return pulumi.get(self, "relevant_host_tags_anded")

    @_builtins.property
    @pulumi.getter(name="runningState")
    def running_state(self) -> _builtins.str:
        """
        The running state of the maintenance window.
        """
        return pulumi.get(self, "running_state")

    @_builtins.property
    @pulumi.getter(name="sortAttr")
    def sort_attr(self) -> _builtins.int:
        return pulumi.get(self, "sort_attr")

    @_builtins.property
    @pulumi.getter(name="startTimeInSeconds")
    def start_time_in_seconds(self) -> _builtins.int:
        """
        The start time in seconds after 1 Jan 1970 GMT.
        """
        return pulumi.get(self, "start_time_in_seconds")

    @_builtins.property
    @pulumi.getter
    def title(self) -> _builtins.str:
        """
        The title of the maintenance window.
        """
        return pulumi.get(self, "title")

    @_builtins.property
    @pulumi.getter(name="updatedEpochMillis")
    def updated_epoch_millis(self) -> _builtins.int:
        """
        The timestamp in epoch milliseconds indicating when the maintenance window is updated.
        """
        return pulumi.get(self, "updated_epoch_millis")

    @_builtins.property
    @pulumi.getter(name="updaterId")
    def updater_id(self) -> _builtins.str:
        """
        The ID of the user who updated the maintenance window.
        """
        return pulumi.get(self, "updater_id")


class AwaitableGetMaintenanceWindowResult(GetMaintenanceWindowResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMaintenanceWindowResult(
            created_epoch_millis=self.created_epoch_millis,
            creator_id=self.creator_id,
            customer_id=self.customer_id,
            end_time_in_seconds=self.end_time_in_seconds,
            event_name=self.event_name,
            host_tag_group_host_names_group_anded=self.host_tag_group_host_names_group_anded,
            id=self.id,
            reason=self.reason,
            relevant_customer_tags=self.relevant_customer_tags,
            relevant_host_names=self.relevant_host_names,
            relevant_host_tags=self.relevant_host_tags,
            relevant_host_tags_anded=self.relevant_host_tags_anded,
            running_state=self.running_state,
            sort_attr=self.sort_attr,
            start_time_in_seconds=self.start_time_in_seconds,
            title=self.title,
            updated_epoch_millis=self.updated_epoch_millis,
            updater_id=self.updater_id)


def get_maintenance_window(id: Optional[_builtins.str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMaintenanceWindowResult:
    """
    Use this data source to get information about a Wavefront maintenance window by its ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get the information about specific maintenance window.
    example = wavefront.get_maintenance_window(id="sample-maintenance-window-id")
    ```


    :param _builtins.str id: The ID of the maintenance window.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('wavefront:index/getMaintenanceWindow:getMaintenanceWindow', __args__, opts=opts, typ=GetMaintenanceWindowResult).value

    return AwaitableGetMaintenanceWindowResult(
        created_epoch_millis=pulumi.get(__ret__, 'created_epoch_millis'),
        creator_id=pulumi.get(__ret__, 'creator_id'),
        customer_id=pulumi.get(__ret__, 'customer_id'),
        end_time_in_seconds=pulumi.get(__ret__, 'end_time_in_seconds'),
        event_name=pulumi.get(__ret__, 'event_name'),
        host_tag_group_host_names_group_anded=pulumi.get(__ret__, 'host_tag_group_host_names_group_anded'),
        id=pulumi.get(__ret__, 'id'),
        reason=pulumi.get(__ret__, 'reason'),
        relevant_customer_tags=pulumi.get(__ret__, 'relevant_customer_tags'),
        relevant_host_names=pulumi.get(__ret__, 'relevant_host_names'),
        relevant_host_tags=pulumi.get(__ret__, 'relevant_host_tags'),
        relevant_host_tags_anded=pulumi.get(__ret__, 'relevant_host_tags_anded'),
        running_state=pulumi.get(__ret__, 'running_state'),
        sort_attr=pulumi.get(__ret__, 'sort_attr'),
        start_time_in_seconds=pulumi.get(__ret__, 'start_time_in_seconds'),
        title=pulumi.get(__ret__, 'title'),
        updated_epoch_millis=pulumi.get(__ret__, 'updated_epoch_millis'),
        updater_id=pulumi.get(__ret__, 'updater_id'))
def get_maintenance_window_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetMaintenanceWindowResult]:
    """
    Use this data source to get information about a Wavefront maintenance window by its ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_wavefront as wavefront

    # Get the information about specific maintenance window.
    example = wavefront.get_maintenance_window(id="sample-maintenance-window-id")
    ```


    :param _builtins.str id: The ID of the maintenance window.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('wavefront:index/getMaintenanceWindow:getMaintenanceWindow', __args__, opts=opts, typ=GetMaintenanceWindowResult)
    return __ret__.apply(lambda __response__: GetMaintenanceWindowResult(
        created_epoch_millis=pulumi.get(__response__, 'created_epoch_millis'),
        creator_id=pulumi.get(__response__, 'creator_id'),
        customer_id=pulumi.get(__response__, 'customer_id'),
        end_time_in_seconds=pulumi.get(__response__, 'end_time_in_seconds'),
        event_name=pulumi.get(__response__, 'event_name'),
        host_tag_group_host_names_group_anded=pulumi.get(__response__, 'host_tag_group_host_names_group_anded'),
        id=pulumi.get(__response__, 'id'),
        reason=pulumi.get(__response__, 'reason'),
        relevant_customer_tags=pulumi.get(__response__, 'relevant_customer_tags'),
        relevant_host_names=pulumi.get(__response__, 'relevant_host_names'),
        relevant_host_tags=pulumi.get(__response__, 'relevant_host_tags'),
        relevant_host_tags_anded=pulumi.get(__response__, 'relevant_host_tags_anded'),
        running_state=pulumi.get(__response__, 'running_state'),
        sort_attr=pulumi.get(__response__, 'sort_attr'),
        start_time_in_seconds=pulumi.get(__response__, 'start_time_in_seconds'),
        title=pulumi.get(__response__, 'title'),
        updated_epoch_millis=pulumi.get(__response__, 'updated_epoch_millis'),
        updater_id=pulumi.get(__response__, 'updater_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ServiceAccountArgs', 'ServiceAccount']

@pulumi.input_type
class ServiceAccountArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 ingestion_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a ServiceAccount resource.
        :param pulumi.Input[_builtins.str] identifier: The unique identifier of the service account to create. Must have the prefix `sa::`.
        :param pulumi.Input[_builtins.bool] active: Whether or not the service account is active.
        :param pulumi.Input[_builtins.str] description: The description of the service account.
        :param pulumi.Input[_builtins.str] ingestion_policy: ID of ingestion policy.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] permissions: List of permission to grant to this service account. Valid options are
               `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
               `host_tag_management`, `metrics_management`, and `user_management`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_groups: List of user groups for this service account.
        """
        pulumi.set(__self__, "identifier", identifier)
        if active is not None:
            pulumi.set(__self__, "active", active)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ingestion_policy is not None:
            pulumi.set(__self__, "ingestion_policy", ingestion_policy)
        if permissions is not None:
            pulumi.set(__self__, "permissions", permissions)
        if user_groups is not None:
            pulumi.set(__self__, "user_groups", user_groups)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        The unique identifier of the service account to create. Must have the prefix `sa::`.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether or not the service account is active.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "active", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the service account.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="ingestionPolicy")
    def ingestion_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of ingestion policy.
        """
        return pulumi.get(self, "ingestion_policy")

    @ingestion_policy.setter
    def ingestion_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ingestion_policy", value)

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of permission to grant to this service account. Valid options are
        `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
        `host_tag_management`, `metrics_management`, and `user_management`.
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "permissions", value)

    @_builtins.property
    @pulumi.getter(name="userGroups")
    def user_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of user groups for this service account.
        """
        return pulumi.get(self, "user_groups")

    @user_groups.setter
    def user_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "user_groups", value)


@pulumi.input_type
class _ServiceAccountState:
    def __init__(__self__, *,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 ingestion_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering ServiceAccount resources.
        :param pulumi.Input[_builtins.bool] active: Whether or not the service account is active.
        :param pulumi.Input[_builtins.str] description: The description of the service account.
        :param pulumi.Input[_builtins.str] identifier: The unique identifier of the service account to create. Must have the prefix `sa::`.
        :param pulumi.Input[_builtins.str] ingestion_policy: ID of ingestion policy.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] permissions: List of permission to grant to this service account. Valid options are
               `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
               `host_tag_management`, `metrics_management`, and `user_management`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_groups: List of user groups for this service account.
        """
        if active is not None:
            pulumi.set(__self__, "active", active)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if ingestion_policy is not None:
            pulumi.set(__self__, "ingestion_policy", ingestion_policy)
        if permissions is not None:
            pulumi.set(__self__, "permissions", permissions)
        if user_groups is not None:
            pulumi.set(__self__, "user_groups", user_groups)

    @_builtins.property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether or not the service account is active.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "active", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the service account.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the service account to create. Must have the prefix `sa::`.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="ingestionPolicy")
    def ingestion_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of ingestion policy.
        """
        return pulumi.get(self, "ingestion_policy")

    @ingestion_policy.setter
    def ingestion_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ingestion_policy", value)

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of permission to grant to this service account. Valid options are
        `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
        `host_tag_management`, `metrics_management`, and `user_management`.
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "permissions", value)

    @_builtins.property
    @pulumi.getter(name="userGroups")
    def user_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of user groups for this service account.
        """
        return pulumi.get(self, "user_groups")

    @user_groups.setter
    def user_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "user_groups", value)


@pulumi.type_token("wavefront:index/serviceAccount:ServiceAccount")
class ServiceAccount(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 ingestion_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Provides a Wavefront Service Account Resource. This allows service accounts to be created, updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        basic = wavefront.ServiceAccount("basic",
            identifier="sa::tftesting",
            active=True)
        ```

        ## Import

        Service accounts can be imported by using `identifier`, e.g.:

        ```sh
        $ pulumi import wavefront:index/serviceAccount:ServiceAccount basic sa::tftesting
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] active: Whether or not the service account is active.
        :param pulumi.Input[_builtins.str] description: The description of the service account.
        :param pulumi.Input[_builtins.str] identifier: The unique identifier of the service account to create. Must have the prefix `sa::`.
        :param pulumi.Input[_builtins.str] ingestion_policy: ID of ingestion policy.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] permissions: List of permission to grant to this service account. Valid options are
               `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
               `host_tag_management`, `metrics_management`, and `user_management`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_groups: List of user groups for this service account.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServiceAccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Wavefront Service Account Resource. This allows service accounts to be created, updated, and deleted.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_wavefront as wavefront

        basic = wavefront.ServiceAccount("basic",
            identifier="sa::tftesting",
            active=True)
        ```

        ## Import

        Service accounts can be imported by using `identifier`, e.g.:

        ```sh
        $ pulumi import wavefront:index/serviceAccount:ServiceAccount basic sa::tftesting
        ```

        :param str resource_name: The name of the resource.
        :param ServiceAccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServiceAccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 ingestion_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServiceAccountArgs.__new__(ServiceAccountArgs)

            __props__.__dict__["active"] = active
            __props__.__dict__["description"] = description
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["ingestion_policy"] = ingestion_policy
            __props__.__dict__["permissions"] = permissions
            __props__.__dict__["user_groups"] = user_groups
        super(ServiceAccount, __self__).__init__(
            'wavefront:index/serviceAccount:ServiceAccount',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active: Optional[pulumi.Input[_builtins.bool]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            ingestion_policy: Optional[pulumi.Input[_builtins.str]] = None,
            permissions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            user_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'ServiceAccount':
        """
        Get an existing ServiceAccount resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] active: Whether or not the service account is active.
        :param pulumi.Input[_builtins.str] description: The description of the service account.
        :param pulumi.Input[_builtins.str] identifier: The unique identifier of the service account to create. Must have the prefix `sa::`.
        :param pulumi.Input[_builtins.str] ingestion_policy: ID of ingestion policy.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] permissions: List of permission to grant to this service account. Valid options are
               `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
               `host_tag_management`, `metrics_management`, and `user_management`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_groups: List of user groups for this service account.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServiceAccountState.__new__(_ServiceAccountState)

        __props__.__dict__["active"] = active
        __props__.__dict__["description"] = description
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["ingestion_policy"] = ingestion_policy
        __props__.__dict__["permissions"] = permissions
        __props__.__dict__["user_groups"] = user_groups
        return ServiceAccount(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def active(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether or not the service account is active.
        """
        return pulumi.get(self, "active")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the service account.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        The unique identifier of the service account to create. Must have the prefix `sa::`.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="ingestionPolicy")
    def ingestion_policy(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        ID of ingestion policy.
        """
        return pulumi.get(self, "ingestion_policy")

    @_builtins.property
    @pulumi.getter
    def permissions(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        List of permission to grant to this service account. Valid options are
        `agent_management`, `alerts_management`, `dashboard_management`, `embedded_charts`, `events_management`, `external_links_management`,
        `host_tag_management`, `metrics_management`, and `user_management`.
        """
        return pulumi.get(self, "permissions")

    @_builtins.property
    @pulumi.getter(name="userGroups")
    def user_groups(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        List of user groups for this service account.
        """
        return pulumi.get(self, "user_groups")

